@@ -2757,7 +2757,7 @@ g_type_value_table_peek (GType type)
    * but we should only get called with referenced types anyway
    */
   data = node ? node->data : NULL;
-  if (node->mutatable_check_cache)
+  if (node && node->mutatable_check_cache)
     return data->common.value_table;
 
   G_READ_LOCK (&type_rw_lock);
@@ -2854,9 +2854,9 @@ g_type_init_with_debug_flags (GTypeDebugFlags debug_flags)
       return;
     }
   
-  /* setup GRuntime wide debugging flags */
+  /* setup GObject library wide debugging flags */
   _g_type_debug_flags = debug_flags & G_TYPE_DEBUG_MASK;
-  env_string = g_getenv ("GRUNTIME_DEBUG");
+  env_string = g_getenv ("GOBJECT_DEBUG");
   if (env_string != NULL)
     {
       static GDebugKey debug_keys[] = {
